==> react-atom-video-player-1.20.0.tgz: package/lib/components/NativePlayer.js <==
import { useEffect, useRef } from 'react';
import PropTypes from 'prop-types';
import useGetBlobAsVideoSrcEffect from '../hooks/native/useGetBlobAsVideoSrcEffect.js';
import useGetSrcWithMediaFragments from '../hooks/native/useGetSrcWithMediaFragments.js';
import { BASE_CLASS, NATIVE_DEFAULT_TITLE } from '../settings/index.js';
import { NATIVE } from '../settings/players.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var NativePlayer = function NativePlayer(_ref) {
  var autoPlay = _ref.autoPlay,
    controls = _ref.controls,
    muted = _ref.muted,
    onLoadVideo = _ref.onLoadVideo,
    timeLimit = _ref.timeLimit,
    timeOffset = _ref.timeOffset,
    src = _ref.src,
    _ref$title = _ref.title,
    title = _ref$title === void 0 ? NATIVE_DEFAULT_TITLE : _ref$title;
  var videoNode = useRef(null);
  var videoSrc = useGetBlobAsVideoSrcEffect({
    src: src,
    videoNode: videoNode
  });
  videoSrc = useGetSrcWithMediaFragments({
    videoSrc: videoSrc,
    timeOffset: timeOffset,
    timeLimit: timeLimit
  });
  useEffect(function () {
    if (autoPlay) {
      videoNode.current.play();
    } else {
      videoNode.current.pause();
    }
  }, [autoPlay]);
  var onLoadedMetadata = function onLoadedMetadata() {
    var _videoNode$current = videoNode.current,
      duration = _videoNode$current.duration,
      videoHeight = _videoNode$current.videoHeight,
      videoWidth = _videoNode$current.videoWidth;
    onLoadVideo({
      src: src,
      type: NATIVE.VIDEO_TYPE,
      duration: duration,
      videoHeight: videoHeight,
      videoWidth: videoWidth
    });
  };
  return /*#__PURE__*/_jsx("div", {
    className: BASE_CLASS + "-nativePlayer",
    children: /*#__PURE__*/_jsxs("video", {
      autoPlay: autoPlay,
      className: BASE_CLASS + "-nativePlayerVideo",
      muted: muted,
      ref: videoNode,
      title: title,
      controls: controls,
      onLoadedMetadata: onLoadedMetadata,
      children: [videoSrc !== null && /*#__PURE__*/_jsx("source", {
        "data-testid": "videosrc",
        src: videoSrc
      }), "Your browser does not support the video tag."]
    })
  });
};
export default NativePlayer;

==> react-atom-video-player-1.25.0.tgz: package/lib/components/NativePlayer.js <==
import { forwardRef, useEffect, useRef } from 'react';
import PropTypes from 'prop-types';
import useGetBlobAsVideoSrcEffect from '../hooks/native/useGetBlobAsVideoSrcEffect.js';
import useGetSrcWithMediaFragments from '../hooks/native/useGetSrcWithMediaFragments.js';
import useImperativeApi from '../hooks/useImperativeApi.js';
import { BASE_CLASS, NATIVE_DEFAULT_TITLE } from '../settings/index.js';
import { NATIVE } from '../settings/players.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var NativePlayer = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var autoPlay = _ref.autoPlay,
    controls = _ref.controls,
    muted = _ref.muted,
    onLoadVideo = _ref.onLoadVideo,
    timeLimit = _ref.timeLimit,
    timeOffset = _ref.timeOffset,
    src = _ref.src,
    _ref$title = _ref.title,
    title = _ref$title === void 0 ? NATIVE_DEFAULT_TITLE : _ref$title;
  var playerRef = useRef(null);
  var videoSrc = useGetBlobAsVideoSrcEffect({
    src: src,
    playerRef: playerRef
  });
  videoSrc = useGetSrcWithMediaFragments({
    videoSrc: videoSrc,
    timeOffset: timeOffset,
    timeLimit: timeLimit
  });
  useEffect(function () {
    if (autoPlay) {
      playerRef.current.play();
    } else {
      playerRef.current.pause();
    }
  }, [autoPlay]);
  useImperativeApi({
    ref: forwardedRef,
    getCurrentTime: function getCurrentTime() {
      return Promise.resolve(playerRef.current.currentTime);
    }
  });
  var onLoadedMetadata = function onLoadedMetadata() {
    var _playerRef$current = playerRef.current,
      duration = _playerRef$current.duration,
      videoHeight = _playerRef$current.videoHeight,
      videoWidth = _playerRef$current.videoWidth;
    onLoadVideo({
      src: src,
      type: NATIVE.VIDEO_TYPE,
      duration: duration,
      videoHeight: videoHeight,
      videoWidth: videoWidth
    });
  };
  return /*#__PURE__*/_jsx("div", {
    className: BASE_CLASS + "-nativePlayer",
    children: /*#__PURE__*/_jsxs("video", {
      autoPlay: autoPlay,
      className: BASE_CLASS + "-nativePlayerVideo",
      muted: muted,
      ref: playerRef,
      title: title,
      controls: controls,
      onLoadedMetadata: onLoadedMetadata,
      children: [videoSrc !== null && /*#__PURE__*/_jsx("source", {
        "data-testid": "videosrc",
        src: videoSrc
      }), "Your browser does not support the video tag."]
    })
  });
});
export default NativePlayer;
